@@ -17,7 +17,7 @@ module Mocha
     def hide_original_method
       if method_exists?(method)
         begin
-          stubbee.class_eval("alias_method :#{hidden_method}, :#{method}", __FILE__, __LINE__)
+          stubbee.send(:alias_method, hidden_method, method)
         rescue NameError
           # deal with nasties like ActiveRecord::Associations::AssociationProxy
         end
@@ -29,13 +29,14 @@ module Mocha
     end
 
     def remove_new_method
-      stubbee.class_eval("remove_method :#{method}", __FILE__, __LINE__)
+      stubbee.send(:remove_method, method)
     end
 
     def restore_original_method
       if method_exists?(hidden_method)
         begin
-          stubbee.class_eval("alias_method :#{method}, :#{hidden_method}; remove_method :#{hidden_method}", __FILE__, __LINE__)
+          stubbee.send(:alias_method, method, hidden_method)
+          stubbee.send(:remove_method, hidden_method)
         rescue NameError
           # deal with nasties like ActiveRecord::Associations::AssociationProxy
         end
@@ -43,11 +44,10 @@ module Mocha
     end
 
     def method_exists?(method)
-      existing_methods = []
-      existing_methods += stubbee.public_instance_methods(false)
-      existing_methods += stubbee.protected_instance_methods(false)
-      existing_methods += stubbee.private_instance_methods(false)
-      existing_methods.any? { |m| m.to_s == method.to_s }
+      return true if stubbee.public_instance_methods(false).include?(method)
+      return true if stubbee.protected_instance_methods(false).include?(method)
+      return true if stubbee.private_instance_methods(false).include?(method)
+      return false
     end
     
   end
