@@ -1,20 +1,22 @@
 require 'test/unit/testresult'
 require 'test/unit/testcase'
-require 'mocha/standalone'
-require 'mocha/test_case_adapter'
 
 module TestRunner
   
   def run_test(test_result = Test::Unit::TestResult.new, &block)
     test_class = Class.new(Test::Unit::TestCase) do
-      include Mocha::Standalone
-      include Mocha::TestCaseAdapter
       define_method(:test_me, &block)
     end
     test = test_class.new(:test_me)
     test.run(test_result) {}
     class << test_result
       attr_reader :failures, :errors
+      def failure_messages
+        failures.map { |failure| failure.message }
+      end
+      def error_messages
+        errors.map { |error| error.message }
+      end
     end
     test_result
   end
